<?php
/**
 * This file is responsible to application report export.
 *
 * @link        https://lenderd.com
 * @since       1.0.0
 *
 * @package     mortgage_application
 * @sub-package mortgage_application/inc/templates
*/
// If this file is called directly, abort.
defined('ABSPATH') or die("Access denied!");
// check user capabilities
if (! current_user_can('manage_options')) {
    return;
}
$license = trim(get_mortgage_application_option('ma_license_key'));
$status  = get_mortgage_application_option('ma_license_key_status');
        if ($status === false || $status == 'invalid' || $license === false) {
            add_settings_error('license-status', 'ma-license-status', __('To upgrade your plugin or get support please visit <a href="https://mortgageapplicationplugin.com">https://mortgageapplicationplugin.com</a>', "mortgage_app"), "error");
            settings_errors('license-status');
        }

?>
<div class="wrap export-application">
	<h1 class="title"><?php echo __('Export Applications', 'mortgage_app'); ?></h1>
    <?php
    //show error or success message after export applications
    if (isset($_GET['export-status']) && !empty($_GET['export-status'])) {
        if (sanitize_text_field($_GET['export-status']) === 'error') {
            $message = "Application not found.";
        } else {
            $message = "Application successfully exported.";
        }
        add_settings_error('export-status', 'ma-export-status', __($message, 'mortgage_app'), sanitize_text_field($_GET['export-status']));
        settings_errors('export-status');
    }
    ?>
    <div class="container">
		<form action="<?php echo admin_url('admin-post.php'); ?>" method="post" enctype="multipart/form-data" name="mortgage_application_export_application">
            <div class="field-row specific-radio-application">
            	<div>
            		<input type="radio"  name="application_type" value="all" checked="checked">
                    <label><?php echo __('All Applications', 'mortgage_app'); ?></label>
                    <input type="radio"  name="application_type" value="100">
                    <label><?php echo __('Complete Applications', 'mortgage_app'); ?></label>
                    <input type="radio"  name="application_type" value="80">
                    <label><?php echo __('Incomplete Applications', 'mortgage_app'); ?></label>
            	</div>
            </div>
            <?php /*?><div class="field-row specific-application" style="display:none">
                <label class="" for="application">
                    <?php echo __( 'Applications', 'mortgage_app' ); ?>
                </label>
                <input type="text" name="applications_search" id="applications_search" class="w-100" placeholder="Enter application title minimum two key"/>
                <select name="applications[]" id="applications" class="w-100" multiple="multiple" style="display:none"></select>
            </div><?php */?>
            <div class="field-row specific-radio-application">
            	<div>
            		<input type="radio" class="select_type" name="application_Fields_type" value="all" checked="checked">
                    <label><?php echo __('Select All Fields', 'mortgage_app'); ?></label>
                    <input type="radio" class="select_type" name="application_Fields_type" value="specific">
                    <label><?php echo __('Select Specific Fields', 'mortgage_app'); ?></label>
            	</div>
            </div>
            <div class="field-row specific-application" style="display:none">
                <label class="" for="application">
                    <?php echo __('Application Fields', 'mortgage_app'); ?>
                </label>
                <input type="text" name="application_field_search" id="application_field_search" class="w-100" placeholder="Enter field name minimum two key"/>
                <select name="application_fields[]" id="application_fields" class="w-100" multiple="multiple" style="display:none"></select>
            </div>
            <div class="field-row condition-select-box">
                <label class="" for="date_range">
                    <?php echo __('Conditional Logic', 'mortgage_app'); ?>
                </label>
                <div class="ma-field-filter">
                    <div class="condition_table">
                                <div class="condition_table_fields">
                                    <select class="arg1" name="key[]">
                                        <option value="">Select Any field</option>
                                        <?php foreach ($mortgage_application_form_fields as $key => $singleMeta) {?>
                                            <option value="<?php echo $key;?>"><?php echo ucfirst($singleMeta);?></option>
                                        <?php }?>
                                    </select>
                                </div>
                                <div class="condition_table_fields">
                                    <select name="compare[]" class="condition"><option value="contains"><?php echo __('contains', 'mortgage_app'); ?></option><option value="is"><?php echo __('is', 'mortgage_app'); ?></option></select>
                                </div>
                                <div class="condition_table_fields">
                                    <input type="text" value="" name="value[]" class="arg2">
                                </div>
                                <div class="condition_table_fields">
                                    <img class="ma-add-button" src="<?php echo MAPP_MORTGAGE_APP_BASE_URL ; ?>assets/img/add.png" alt="Add a condition" title="Add a condition">
                                    <img class="ma-remove-button" src="<?php echo MAPP_MORTGAGE_APP_BASE_URL ; ?>assets/img/remove.png" alt="Remove a condition" title="Remove a condition">
                                </div>
                    </div>
                </div>
            </div>
            <div class="field-row date_range_class">
                <label class="" for="date_range">
                    <?php echo __('Select a Date range', 'mortgage_app'); ?>
                </label>
                <?php echo __('Start Date', 'mortgage_app'); ?>:<input type="date" name="startDate" class="startDate" />
                <?php echo __('End Date', 'mortgage_app'); ?>:<input type="date" name="endDate" class="endDate" />
            </div>
            <div class="field-row export_type_class">
                <label class="" for="export">
                    <?php echo __('Select Export file type', 'mortgage_app'); ?>
                </label>
                <select name="export_type" id="export">
                    <option value="csv"><?php echo __('CSV', 'mortgage_app'); ?></option>
                    <?php
                            if ($status !== false && $status == 'valid' && $license !== false) {
                                ?>
	 	                        <option value="fnm"><?php echo __('FANNIE 3.2', 'mortgage_app'); ?></option>
                                <option value="mismo"><?php echo __('Mismo 3.4', 'mortgage_app'); ?></option>
	 	                    <?php
                            }
                   ?>
                </select>
            </div>
            <div class="field-row">
            	<input type="hidden" name="action" value="mortgage_application_export_applications">
                <?php wp_nonce_field('mortgage_application_export_applications', 'mortgage_application_export_nonce'); ?>
  				<input type="submit" id="export_application" name="export_application" class="button-primary" value="<?php echo __('Download Export File', 'mortgage_app'); ?>">
            </div>
        </form>
	</div>
</div>
